function Ihu=getInterpolant_coarse_to_fine(uh,no_basis_z,no_basis_mu,elem,phi,x,w,xc,wc,extra_z,extra_mu)
% compute the interpolant Ihu, which is defined on a once refined mesh, of
% uh defined on coarse mesh. Here each element is assumed to be split in 4
% new elements bottom-left (bl), bottom-right (br), top-right (tr), and
% top-left (tl). (This ordering is/must be consistend with the ordering in
% the refinement routine; otherwise modify line 38).
Ihu=zeros((no_basis_z+extra_z)*(no_basis_mu+extra_mu),4*size(elem,2));
uh=reshape(uh,no_basis_mu*no_basis_z,size(elem,2));
for it=1:size(elem,2) % loop over the coarse elements
    uc_coord=reshape(uh(:,it),no_basis_mu,no_basis_z);
    Ihu_loc_bl=zeros(no_basis_mu+extra_mu,no_basis_z+extra_z);
    Ihu_loc_br=zeros(no_basis_mu+extra_mu,no_basis_z+extra_z);
    Ihu_loc_tr=zeros(no_basis_mu+extra_mu,no_basis_z+extra_z);
    Ihu_loc_tl=zeros(no_basis_mu+extra_mu,no_basis_z+extra_z);
    uc_eval_ip_bl = zeros(length(x),length(xc)); % values of u_h stored in the integration of K1
    uc_eval_ip_br = zeros(length(x),length(xc)); % values of u_h stored in the integration of K2
    uc_eval_ip_tr = zeros(length(x),length(xc)); % values of u_h stored in the integration of K3
    uc_eval_ip_tl = zeros(length(x),length(xc)); % values of u_h stored in the integration of K4
    for i=1:no_basis_z
        for j=1:no_basis_mu
            uc_eval_ip_bl = uc_eval_ip_bl + uc_coord(j,i)*phi{i}(x/2)*phi{j}(xc'/2); % bottom left subelement
            uc_eval_ip_br = uc_eval_ip_br + uc_coord(j,i)*phi{i}(x/2+1/2)*phi{j}(xc'/2); % bottom right subelement
            uc_eval_ip_tr = uc_eval_ip_tr + uc_coord(j,i)*phi{i}(x/2+1/2)*phi{j}(xc'/2 +1/2); % top right subelement
            uc_eval_ip_tl = uc_eval_ip_tl + uc_coord(j,i)*phi{i}(x/2)*phi{j}(xc'/2 +1/2); % top left subelement
        end
    end
    for j=1:no_basis_mu %+extra_mu
        for i=1:no_basis_z %+extra_z
            eval_basis = phi{i}(x)*phi{j}(xc'); % length(x) x length(xc) matrix; entries are evaluation of basis function (j,i) in all quadrature points.
            Ihu_loc_bl(j,i) = w'*(uc_eval_ip_bl.*eval_basis)*wc; % compute (int_K1 u_c b_{i,j} d(z,mu))/|K1| Here b_{i,j} is a basis function corresponding to K1
            Ihu_loc_br(j,i) = w'*(uc_eval_ip_br.*eval_basis)*wc; % compute (int_K2 u_c b_{i,j} d(z,mu))/|K2| Here b_{i,j} is a basis function corresponding to K2
            Ihu_loc_tr(j,i) = w'*(uc_eval_ip_tr.*eval_basis)*wc; % compute (int_K3 u_c b_{i,j} d(z,mu))/|K3| Here b_{i,j} is a basis function corresponding to K3
            Ihu_loc_tl(j,i) = w'*(uc_eval_ip_tl.*eval_basis)*wc; % compute (int_K4 u_c b_{i,j} d(z,mu))/|K4| Here b_{i,j} is a basis function corresponding to K4
        end
    end
    Ihu(:,4*(it-1)+1:4*it)=[Ihu_loc_bl(:) Ihu_loc_br(:) Ihu_loc_tr(:) Ihu_loc_tl(:)] ;
end
Ihu=Ihu(:);
end