function [ux,dux,d2ux,qx,gLx,gRx,sigmat,sigmas]=loadTestCase1()
%% This test case is according to Section 4 of 
%% Riccardo Bardin, Fleurianne Bertrand, Olena Palii, Matthias Schlottbom
%% On a phase-space discontinuous Galerkin approximation for the radiative transfer equation in slab geometry.
%% Computational Methods in Applied Mathematics, doi: 10.1515/cmam-2023-0090
%% https://arxiv.org/abs/2201.06104

%% specify optical parameters
sigmat=@(z) 1.0+0*z; % total extinction coefficient.
sigmas=@(z) 0.5+0*z; % scattering coefficient.

%% specify exact solution for test case
f1=@(mu) (1+exp(-mu)).*(mu>1/2);
f2=@(x)exp(-x.^2)+0*x;
df2=@(x)-2*x.*f2(x)+0*x;
d2f2=@(x)-2*f2(x)+4*x.^2.*f2(x)+0*x;
ux=@(x,mu)f1(mu).*f2(x);    % exact solution
dux=@(x,mu)f1(mu).*df2(x);  % x-derivative exact solution
d2ux=@(x,mu)f1(mu).*d2f2(x);% xx-derivative exact solution

int_f1=integral(f1,0,1,"RelTol",1e-13); % compute angular average numerically

%% specify source functions
qx=@(z,mu) -mu.^2./sigmat(z).*d2ux(z,mu)+sigmat(z).*ux(z,mu)-(sigmas(z).*f2(z))*int_f1; % internal source
gLx=@(mu)ux(0,mu)-(mu.*dux(0,mu))/sigmat(0); % Robin boundary condition left
gRx=@(mu)ux(1,mu)+(mu.*dux(1,mu))/sigmat(1); % Robin boundary condition right