function [ux,dux,d2ux,qx,gLx,gRx,sigmat,sigmas]=loadTestCase2()
%% This test case is according to Section 5, (26) of 
%% Riccardo Bardin, Fleurianne Bertrand, Olena Palii, Matthias Schlottbom
%% On a phase-space discontinuous Galerkin approximation for the radiative transfer equation in slab geometry.
%% Computational Methods in Applied Mathematics, doi: 10.1515/cmam-2023-0090
%% https://arxiv.org/abs/2201.06104

%% specify optical parameters
sigmat=@(z) 1.0+0*z; % total extinction coefficient.
sigmas=@(z) 0.0+0*z; % scattering coefficient.

alpha=1/4;
ux=@(x,mu)(mu.^2+x.^2).^alpha; % exact solution
dux=@(x,mu)alpha*(mu.^2+x.^2).^(alpha-1).*(2*x);    % x-derivative
d2ux=@(x,mu)alpha*(mu.^2+x.^2).^(alpha-1).*(2)+alpha*(alpha-1)*(mu.^2+x.^2).^(alpha-2).*(2*x).^2; % xx-derivative
intu=@(x,mu)0; % arbitrary, because sigmas=0;

%% specify source functions
qx=@(z,mu) -mu.^2./sigmat(z).*d2ux(z,mu)+sigmat(z).*ux(z,mu)-sigmas(z).*intu(z,mu);
gLx=@(mu)ux(0,mu)-(mu.*dux(0,mu))/sigmat(0); % Robin boundary condition left
gRx=@(mu)ux(1,mu)+(mu.*dux(1,mu))/sigmat(1); % Robin boundary condition right
