function [elem_new,nodes_new,edges_new,edge2elem_new,int_edges_new]=refine_quad(elem,nodes,edges,edge2elem,tbr)
% elem(5,:) level
% elem(6,:) index of uniform grid
% elem=[1;2;3;4;0;1];edges=[1,2,3,1;2,3,4,4];nodes=[0,1,1,0;0,0,1,1];hmin=1;
% elem=elem_new;nodes=nodes_new;edges=edges_new;hmin=hmin/2;

% !!! only vertical edges are inserted in edges_new !!!

hmin=(1/2).^max(elem(5,:));
level=elem(5,tbr);
k=elem(6,tbr);
[i,j]=ind2sub([2^level,2^level],k);
bl=sub2ind([2^(level+1),2^(level+1)],2*i-1,2*j-1);
br=sub2ind([2^(level+1),2^(level+1)],2*i,2*j-1);
tl=sub2ind([2^(level+1),2^(level+1)],2*i-1,2*j);
tr=sub2ind([2^(level+1),2^(level+1)],2*i,2*j);

ed_loc=[elem(1,tbr),elem(2,tbr),elem(4,tbr),elem(1,tbr);...
    elem(2,tbr),elem(3,tbr),elem(3,tbr),elem(4,tbr)]; % all 4 local edges, oriented increasing in z or in mu.


[ed_loc,sort_ind_ed_loc]=sort(ed_loc); % in sort_in_ed_loc we see whether edge indices have been flipped.

elem_new=zeros(6,size(elem,2)+3); % 3 extra elements will be created
elem_new(:,1:tbr-1)=elem(:,1:tbr-1);
elem_new(:,tbr+4:end)=elem(:,tbr+1:end);

edges_new=[];
edge2elem_new=[];

reindex=(edge2elem>tbr);
edge2elem(reindex)=edge2elem(reindex)+3;

number_of_new_nodes=0;
nodes_new=nodes;
edge_mid=0.5*(nodes(:,ed_loc(1,:))+nodes(:,ed_loc(2,:))); % 2 midpoints of local vertical edges
mid=0.5*(edge_mid(:,1)+edge_mid(:,3)); % point in the middle of the element.
ind_edge_nodes=zeros(1,4);
new_ind=[];
to_be_deleted=[];
for it=1:4 % two local vertical edges will be considered. We have to find out whether on that local edge there is already a hanging node.
    ind=find(ismember(edges',ed_loc(:,it)','rows')); % check whether local edge is in edge list. If yes, then we need to remove it. Also then there is no hanging node.
    ind2=find(sum((nodes-edge_mid(:,it)).^2,1)<(hmin/2)^2); % is the index of the existing hanging node
    % if local edge is in edgelist, then no hanging node on local edge.
    % otherwise, local edge contains hanging node and no new node/edge is to be
    % inserted
    %     if (isempty(ind2) && isempty(ind)) || (~isempty(ind2) && isempty(ind))
    %         fprintf('Error\n')
    %     end
    if isempty(ind2) % no hanging node -> insert new point -> 2 new vertical edges created
        number_of_new_nodes=number_of_new_nodes+1;
        new_ind=[new_ind;it];
        ind_edge_nodes(it)=size(nodes,2)+number_of_new_nodes;
        nodes_new=[nodes_new,edge_mid(:,it)];
        if ismember(it,[2,4]) % consider only vertical edges
            edges_new=[edges_new,[ed_loc(1,it),ed_loc(2,it);ind_edge_nodes(it),ind_edge_nodes(it)]];
            %         if it==1 % first local edge, is on the right of element tbr.
            el_left=edge2elem(1,ind);
            el_right=edge2elem(2,ind);
            if el_left==tbr
                if sort_ind_ed_loc(1,it)==1 % edge not flipped
                    edge2elem_new=[edge2elem_new, [tbr+1, tbr+2;el_right, el_right]]; % elements tbr+1 and tbr+2 are the ones on the right.
                else
                    edge2elem_new=[edge2elem_new, [tbr+2, tbr+1;el_right, el_right]]; % elements tbr+2 and tbr+1 are the ones on the right.
                end
            else %el_right=tbr
                if sort_ind_ed_loc(1,it)==1 % edge not flipped
                    edge2elem_new=[edge2elem_new, [el_left, el_left;tbr,tbr+3]];
                else
                    edge2elem_new=[edge2elem_new, [el_left, el_left;tbr+3,tbr]];
                end
            end
            to_be_deleted=[to_be_deleted,ind];
        end

    else % hanging node -> find index of it -> ind2. No new edges created. But updated the neighbor relations for the edges
        %         node_local=edge_mid(:,it);
        %         ind2=find(sum((nodes-nodes(:,node_local)).^2,2)<(hmin/2)^2);
        ind_edge_nodes(it)=ind2;
        % TODO: Also in this in this case the corresponding edges2elem
        % needs and update!
    end
end
ind_edge_nodes=[ind_edge_nodes,size(nodes,2)+number_of_new_nodes+1];% the last is the midpoint of the element
edges_to_be_kept=setdiff(1:size(edges,2),to_be_deleted);
edges_new    =[edges(:,edges_to_be_kept),edges_new,[ind_edge_nodes(1),ind_edge_nodes(3);ind_edge_nodes(5),ind_edge_nodes(5)]]; % the last two edges connect the element midpoint vertically
edge2elem_new=[edge2elem(:,edges_to_be_kept),edge2elem_new,[tbr,tbr+3;tbr+1,tbr+2]];
edges_new=sort(edges_new); % sort edges_new so that first index is smaller than second index for each edges_new(:,it)
[order,i]=sort(edges_new(1,:)); % order the edges increasingly in the first component
edges_new=edges_new(:,i); % re-order the edges increasingly in the first component
edge2elem_new=edge2elem_new(:,i); % re-order the edge2elem list as well
nodes_new=[nodes_new,mid];
elem_new(:,tbr:tbr+3)=[elem(1,tbr)      , ind_edge_nodes(1), ind_edge_nodes(5),ind_edge_nodes(4); ...
    ind_edge_nodes(1), elem(2,tbr)      , ind_edge_nodes(2),ind_edge_nodes(5) ;...
    ind_edge_nodes(5), ind_edge_nodes(2), elem(3,tbr)      ,ind_edge_nodes(3) ;...
    ind_edge_nodes(4), ind_edge_nodes(5), ind_edge_nodes(3),elem(4,tbr) ; ...
    level+1,           level+1          , level+1,          level+1; ...
    bl,                br               , tr     ,           tl];
% there might still be edges that point to element tbr in the wrong way
ind1=find(edge2elem_new(1,:)==tbr); % point to tbr as left neighbor, which cannot be - except for newly added edges in the middle!!!!
ind2=find(edge2elem_new(2,:)==tbr); % point to tbr as right neighbor, but may also be tbr+3
for i=ind1
    edge_mid=0.5*(nodes_new(:,edges_new(1,i))+nodes_new(:,edges_new(2,i))); % coordinate midpoint edges
    if abs(edge_mid(1)-mid(1))>hmin/4
        if edge_mid(2)>mid(2)
            edge2elem_new(1,i)=tbr+2;
        else
            edge2elem_new(1,i)=tbr+1;
        end
    end
end
for i=ind2
    edge_mid=0.5*(nodes_new(:,edges_new(1,i))+nodes_new(:,edges_new(2,i))); % mu-coordinate midpoint edges
    if abs(edge_mid(1)-mid(1))>hmin/4
        if edge_mid(2)>mid(2)
            edge2elem_new(2,i)=tbr+3;
            %     else
            %         edge2elem_new(2,i)=tbr;
        end
    end
end
int_edges_new=find((edge2elem_new(1,:)>0)&(edge2elem_new(2,:)>0)); %interior faces
end